@@ -1,13 +1,7 @@
 /*
- * $Id: Page.cs 138 2006-12-23 17:11:57Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Engine/Page.cs $
- * $Rev: 138 $
- * $Author: meebey $
- * $Date: 2006-12-23 18:11:57 +0100 (Sat, 23 Dec 2006) $
- *
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2005-2008 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2005-2008, 2010 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -27,6 +21,7 @@
  */
 
 using System;
+using System.IO;
 using System.Collections;
 using System.Collections.Generic;
 using Smuxi.Common;
@@ -35,6 +30,9 @@ namespace Smuxi.Engine
 {
     public abstract class ChatModel : PermanentRemoteObject, ITraceable
     {
+#if LOG4NET
+        private static readonly log4net.ILog _Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
+#endif
         private string               _ID;
         private string               _Name;
         private ChatType             _ChatType;
@@ -42,7 +40,9 @@ namespace Smuxi.Engine
         private List<MessageModel>   _Messages = new List<MessageModel>();
         private bool                 _IsEnabled = true;
         private DateTime             _LastSeenHighlight;
-        
+        private string               _LogFile;
+        public  int                  Position { get; set; }
+
         public string ID {
             get {
                 return _ID;
@@ -101,13 +101,23 @@ namespace Smuxi.Engine
                 _LastSeenHighlight = value;
             }
         }
-        
+
+        public string LogFile {
+            get {
+                if (_LogFile == null) {
+                    _LogFile = GetLogFile();
+                }
+                return _LogFile;
+            }
+        }
+
         protected ChatModel(string id, string name, ChatType chatType, IProtocolManager networkManager)
         {
             _ID = id;
             _Name = name;
             _ChatType = chatType;
             _ProtocolManager = networkManager;
+            Position = -1;
         }
         
         public string ToTraceString()
@@ -115,5 +125,55 @@ namespace Smuxi.Engine
             string nm = (_ProtocolManager != null) ? _ProtocolManager.ToString() : "(null)";  
             return  nm + "/" + _Name; 
         }
+        
+        private string GetLogFile()
+        {
+            if (_ProtocolManager == null) {
+                return null;
+            }
+
+            var logPath = Platform.LogPath;
+            var protocol = _ProtocolManager.Protocol.ToLower();
+            var network = _ProtocolManager.NetworkID.ToLower();
+            logPath = Path.Combine(logPath, protocol);
+            if (network != protocol) {
+                logPath = Path.Combine(logPath, network);
+            }
+            if (logPath.IndexOfAny(Path.GetInvalidPathChars()) != -1) {
+#if LOG4NET
+                _Logger.Warn(
+                    "GetLogFile(): logPath '" + logPath + "' contains " +
+                     "invalid chars, removing them!"
+                );
+#endif
+                // remove invalid chars
+                foreach (char invalidChar in Path.GetInvalidPathChars()) {
+                    logPath = logPath.Replace(invalidChar.ToString(),
+                                              String.Empty);
+                }
+            }
+
+            if (!Directory.Exists(logPath)) {
+                Directory.CreateDirectory(logPath);
+            }
+            
+            var chatId = ID.Replace(" ", "_").ToLower();
+            if (chatId.IndexOfAny(Path.GetInvalidFileNameChars()) != -1) {
+#if LOG4NET
+                _Logger.Warn(
+                    "GetLogFile(): chatId '" + logPath + "' contains " +
+                     "invalid chars, removing them!"
+                );
+#endif
+                // remove invalid chars
+                foreach (char invalidChar in Path.GetInvalidFileNameChars()) {
+                    chatId = chatId.Replace(invalidChar.ToString(),
+                                            String.Empty);
+                }
+            }
+            logPath = Path.Combine(logPath, String.Format("{0}.log", chatId));
+            logPath = logPath.Replace("..", String.Empty);
+            return logPath;
+        }
     }
 }
