@@ -238,6 +238,9 @@ namespace Smuxi.Engine
             Get(prefix+"Channel", "TCP");
             Get(prefix+"Formatter", "binary");
             
+            prefix = "Engine/Users/DEFAULT/Interface/";
+            Get(prefix+"ShowAdvancedSettings", false);
+
             prefix = "Engine/Users/DEFAULT/Interface/Notebook/";
             Get(prefix+"TimestampFormat", "HH:mm");
             Get(prefix+"TabPosition", "top");
@@ -272,14 +275,21 @@ namespace Smuxi.Engine
             Get(prefix+"CommandHistorySize", 30);
 
             prefix = "Engine/Users/DEFAULT/Interface/Notification/";
-            Get(prefix+"NotificationAreaIconMode", "Minimized");
+            Get(prefix+"NotificationAreaIconMode", "Never");
+            Get(prefix+"MessagingMenuEnabled", true);
+            Get(prefix+"PopupsEnabled", true);
 
             prefix = "Engine/Users/DEFAULT/Sound/";
             Get(prefix+"BeepOnHighlight", false);
             
             prefix = "Engine/Users/DEFAULT/Connection/";
             Get(prefix+"Encoding", String.Empty);
-            
+            Get(prefix+"ProxyType", "None");
+            Get(prefix+"ProxyHostname", String.Empty);
+            Get(prefix+"ProxyPort", -1);
+            Get(prefix+"ProxyUsername", String.Empty);
+            Get(prefix+"ProxyPassword", String.Empty);
+
             prefix = "Engine/Users/DEFAULT/Logging/";
             Get(prefix+"Enabled", false);
             Get(prefix+"LogFilteredMessages", false);
@@ -299,6 +309,8 @@ namespace Smuxi.Engine
             Get(prefix + "Network", "OFTC");
             Get(prefix + "Username", String.Empty);
             Get(prefix + "Password", String.Empty);
+            Get(prefix + "UseEncryption", false);
+            Get(prefix + "ValidateServerCertificate", false);
             Get(prefix + "OnStartupConnect", true);
             Get(prefix + "OnConnectCommands",
                 new string[] {
@@ -312,6 +324,8 @@ namespace Smuxi.Engine
             Get(prefix + "Network", "GIMPNet");
             Get(prefix + "Username", String.Empty);
             Get(prefix + "Password", String.Empty);
+            Get(prefix + "UseEncryption", false);
+            Get(prefix + "ValidateServerCertificate", false);
 
             prefix = "Engine/Users/DEFAULT/Servers/IRC/irc.efnet.org/";
             Get(prefix + "Hostname", "irc.efnet.org");
@@ -319,6 +333,8 @@ namespace Smuxi.Engine
             Get(prefix + "Network", "EFnet");
             Get(prefix + "Username", String.Empty);
             Get(prefix + "Password", String.Empty);
+            Get(prefix + "UseEncryption", false);
+            Get(prefix + "ValidateServerCertificate", false);
                 
             prefix = "Engine/Users/DEFAULT/Servers/IRC/irc.ircnet.org/";
             Get(prefix + "Hostname", "irc.ircnet.org");
@@ -326,6 +342,8 @@ namespace Smuxi.Engine
             Get(prefix + "Network", "IRCnet");
             Get(prefix + "Username", String.Empty);
             Get(prefix + "Password", String.Empty);
+            Get(prefix + "UseEncryption", false);
+            Get(prefix + "ValidateServerCertificate", false);
                 
             prefix = "Engine/Users/DEFAULT/Servers/IRC/irc.freenode.net/";
             Get(prefix + "Hostname", "irc.freenode.net");
@@ -333,6 +351,8 @@ namespace Smuxi.Engine
             Get(prefix + "Network", "freenode");
             Get(prefix + "Username", String.Empty);
             Get(prefix + "Password", String.Empty);
+            Get(prefix + "UseEncryption", false);
+            Get(prefix + "ValidateServerCertificate", false);
             
             prefix = "Engine/Users/";
             Get(prefix+"Users", new string[] { "local" });
@@ -400,7 +420,13 @@ namespace Smuxi.Engine
                 }
                 LoadUserEntry(user, "Connection/Realname", realname);
                 LoadUserEntry(user, "Connection/Encoding", String.Empty);
-                
+
+                LoadUserEntry(user, "Connection/ProxyType", "None");
+                LoadUserEntry(user, "Connection/ProxyHostname", String.Empty);
+                LoadUserEntry(user, "Connection/ProxyPort", -1);
+                LoadUserEntry(user, "Connection/ProxyUsername", null);
+                LoadUserEntry(user, "Connection/ProxyPassword", null);
+
                 string[] command_list = GetList(prefix+user+"/Connection/OnConnectCommands");
                 if (command_list != null) {
                     m_Preferences[prefix+user+"/Connection/OnConnectCommands"] = command_list;
@@ -415,6 +441,7 @@ namespace Smuxi.Engine
                     m_Preferences[prefix+user+"/Interface/Chat/HighlightWords"] = new string[] {};
                 }
 
+                LoadUserEntry(user, "Interface/ShowAdvancedSettings", null);
                 LoadUserEntry(user, "Interface/Notebook/TimestampFormat", null);
                 LoadUserEntry(user, "Interface/Notebook/TabPosition", null);
                 LoadUserEntry(user, "Interface/Notebook/BufferLines", null);
@@ -439,6 +466,8 @@ namespace Smuxi.Engine
                 LoadUserEntry(user, "Interface/Entry/BashStyleCompletion", null);
                 LoadUserEntry(user, "Interface/Entry/CommandHistorySize", null);
                 LoadUserEntry(user, "Interface/Notification/NotificationAreaIconMode", null);
+                LoadUserEntry(user, "Interface/Notification/MessagingMenuEnabled", null);
+                LoadUserEntry(user, "Interface/Notification/PopupsEnabled", null);
                 
                 LoadUserEntry(user, "Sound/BeepOnHighlight", null);
                 
@@ -470,6 +499,10 @@ namespace Smuxi.Engine
                                       Get(dprefix + server + "/Username", null));
                             LoadEntry(sprefix + server + "/Password",
                                       Get(dprefix + server + "/Password", null));
+                            LoadEntry(sprefix + server + "/UseEncryption",
+                                      Get(dprefix + server + "/UseEncryption", null));
+                            LoadEntry(sprefix + server + "/ValidateServerCertificate",
+                                      Get(dprefix + server + "/ValidateServerCertificate", null));
                             LoadEntry(sprefix + server + "/OnStartupConnect",
                                       Get(dprefix + server + "/OnStartupConnect", null));
                             LoadEntry(sprefix + server + "/OnConnectCommands",
@@ -489,6 +522,8 @@ namespace Smuxi.Engine
                     LoadEntry(sprefix+"Encoding", null);
                     LoadEntry(sprefix+"Username", String.Empty);
                     LoadEntry(sprefix+"Password", String.Empty);
+                    LoadEntry(sprefix+"UseEncryption", false);
+                    LoadEntry(sprefix+"ValidateServerCertificate", false);
                     LoadEntry(sprefix+"OnStartupConnect", false);
                     string[] commands = GetList(sprefix + "OnConnectCommands");
                     if (commands == null) {
