@@ -120,7 +120,7 @@ namespace Smuxi.Engine
             _Filters = _FilterListController.GetFilterList().Values;
             _Chats = new List<ChatModel>();
             
-            _SessionChat = new SessionChatModel("smuxi", "smuxi");
+            _SessionChat = new SessionChatModel("smuxi", "Smuxi");
             _Chats.Add(_SessionChat);
         }
 
@@ -257,6 +257,8 @@ namespace Smuxi.Engine
             f_Logger.Debug("DeregisterFrontendUI(fm): disposing FrontendManager");
 #endif
             fm.Dispose();
+
+            CheckPresenceStatus();
         }
         
         public void DeregisterFrontendUI(IFrontendUI ui)
@@ -286,6 +288,8 @@ namespace Smuxi.Engine
 #endif
                 manager.Dispose();
             }
+
+            CheckPresenceStatus();
         }
         
         public FrontendManager GetFrontendManager(IFrontendUI ui)
@@ -521,33 +525,38 @@ namespace Smuxi.Engine
             }
             
             FrontendManager fm = cd.FrontendManager;
+            IProtocolManager victim = null;
             if (cd.DataArray.Length >= 2) {
                 string server = cd.DataArray[1];
                 lock (_ProtocolManagers) {
                     foreach (IProtocolManager nm in _ProtocolManagers) {
                         if (nm.Host.ToLower() == server.ToLower()) {
-                            nm.Disconnect(fm);
-                            _ProtocolManagers.Remove(nm);
-                            return;
+                            victim = nm;
+                            break;
                         }
                     }
                 }
-                fm.AddTextToChat(
-                    cd.Chat,
-                    "-!- " +
-                    String.Format(
-                        _("Disconnect failed - could not find server: {0}"),
-                        server
-                    )
-                );
-            } else {
-                var pm = cd.Chat.ProtocolManager;
-                if (pm == null) {
+                if (victim == null) {
+                    fm.AddTextToChat(
+                        cd.Chat,
+                        "-!- " +
+                        String.Format(
+                            _("Disconnect failed - could not find server: {0}"),
+                            server
+                        )
+                    );
                     return;
                 }
-                pm.Disconnect(fm);
-                _ProtocolManagers.Remove(pm);
+            } else {
+                victim = cd.Chat.ProtocolManager;
             }
+
+            if (victim == null) {
+                return;
+            }
+            victim.Disconnect(fm);
+            victim.Dispose();
+            _ProtocolManagers.Remove(victim);
         }
         
         public void CommandReconnect(CommandModel cd)
@@ -677,13 +686,24 @@ namespace Smuxi.Engine
                 pm = cd.Chat.ProtocolManager;
             }
 
-            if (pm != null) {
-                pm.Disconnect(fm);
-                pm.Dispose();
-                // Dispose() takes care of removing the chat from session (frontends)
-                _ProtocolManagers.Remove(pm);
-                fm.NextProtocolManager();
+            if (pm == null) {
+                return;
             }
+
+            // disconnect in background as could be blocking
+            ThreadPool.QueueUserWorkItem(delegate {
+                try {
+                    pm.Disconnect(fm);
+                    pm.Dispose();
+                    // Dispose() takes care of removing the chat from session (frontends)
+                    _ProtocolManagers.Remove(pm);
+                    fm.NextProtocolManager();
+                } catch (Exception ex) {
+#if LOG4NET
+                    f_Logger.Error("_CommandNetworkClose(): Exception", ex);
+#endif
+                }
+            });
         }
         
         private void _CommandNetworkSwitch(CommandModel cd)
@@ -1112,24 +1132,13 @@ namespace Smuxi.Engine
             }
 
             try {
-                var logPath = Platform.LogPath;
-                var protocol = chat.ProtocolManager.Protocol.ToLower();
                 // HACK: twitter retrieves older messages and we don't want to
                 // re-log those when the twitter connection is re-opened
+                var protocol = chat.ProtocolManager.Protocol.ToLower();
                 if (protocol == "twitter") {
                     return;
                 }
-                var network = chat.ProtocolManager.NetworkID.ToLower();
-                logPath = Path.Combine(logPath, protocol);
-                if (network != protocol) {
-                    logPath = Path.Combine(logPath, network);
-                }
-                if (!Directory.Exists(logPath)) {
-                    Directory.CreateDirectory(logPath);
-                }
-                var chatId = chat.ID.Replace(" ", "_").ToLower();
-                logPath = Path.Combine(logPath, String.Format("{0}.log", chatId));
-                using (var stream = File.AppendText(logPath)) {
+                using (var stream = File.AppendText(chat.LogFile)) {
                     stream.WriteLine(
                         String.Format(
                             "[{0:yyyy-MM-dd HH:mm:ss}] {1}",
@@ -1216,6 +1225,37 @@ namespace Smuxi.Engine
             }
        }
 
+        public void CheckPresenceStatus()
+        {
+            Trace.Call();
+
+            var newStatus = PresenceStatus.Unknown;
+            var newMessage = String.Empty;
+            lock (_FrontendManagers) {
+                if (_FrontendManagers.Count == 0) {
+                    newStatus = PresenceStatus.Away;
+                    newMessage = "away from keyboard";
+                } else {
+                    newStatus = PresenceStatus.Online;
+                }
+            }
+
+            if (newStatus == PresenceStatus.Unknown) {
+                return;
+            }
+
+            UpdatePresenceStatus(newStatus, newMessage);
+        }
+
+        void UpdatePresenceStatus(PresenceStatus status, string message)
+        {
+            lock (_ProtocolManagers) {
+                foreach (var manager in _ProtocolManagers) {
+                    manager.SetPresenceStatus(status, message);
+                }
+            }
+        }
+
         private static string _(string msg)
         {
             return LibraryCatalog.GetString(msg, _LibraryTextDomain);
