@@ -213,11 +213,11 @@ namespace Smuxi.Frontend.Gnome
  
             _MainWindow = new MainWindow();
 
-            if (String.IsNullOrEmpty((string) FrontendConfig["Engines/Default"])) {
+            if (((string[]) FrontendConfig["Engines/Engines"]).Length == 0) {
                 InitLocalEngine();
                 ConnectEngineToGUI();
             } else {
-                // there is a default engine set, means we want a remote engine
+                // there are remote engines defined, means we have to ask
                 //_SplashScreenWindow.Destroy();
                 _SplashScreenWindow = null;
                 ShowEngineManagerDialog();
@@ -309,6 +309,11 @@ namespace Smuxi.Frontend.Gnome
             Trace.Call();
 
             try {
+                // sync tab positions
+                if (!IsLocalEngine) {
+                    _MainWindow.Notebook.SyncPagePositions();
+                }
+
                 if (_FrontendManager != null) {
                     _FrontendManager.IsFrontendDisconnecting = true;
                 }
