@@ -30,6 +30,7 @@ using System;
 using System.IO;
 using System.Threading;
 using System.Reflection;
+using SysDiag = System.Diagnostics;
 using Mono.Unix;
 using Smuxi.Common;
 using Smuxi.Engine;
@@ -41,6 +42,8 @@ namespace Smuxi.Frontend.Gnome
 #if LOG4NET
         private static readonly log4net.ILog f_Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
 #endif
+        private Gtk.MenuBar      _MenuBar;
+        private Gtk.CheckMenuItem _ShowMenuBarItem;
         private Gtk.Statusbar    _NetworkStatusbar;
         private Gtk.Statusbar    _Statusbar;
         private Gtk.ProgressBar  _ProgressBar;
@@ -51,13 +54,30 @@ namespace Smuxi.Frontend.Gnome
         private IFrontendUI      _UI;
         private EngineManager    _EngineManager;
         private Gtk.MenuItem     _CloseChatMenuItem;
+        private Gtk.ImageMenuItem _OpenLogChatMenuItem;
         private NotificationAreaIconMode _NotificationAreaIconMode;
 #if GTK_SHARP_2_10
         private StatusIconManager _StatusIconManager;
+#endif
+#if INDICATE_SHARP
+        private IndicateManager  _IndicateManager;
+#endif
+#if NOTIFY_SHARP
+        private NotifyManager    _NotifyManager;
 #endif
         private bool             _IsMinimized;
         private bool             _IsMaximized;
+        private bool             _IsFullscreen;
         
+        public bool ShowMenuBar {
+            get {
+                return _MenuBar.Visible;
+            }
+            set {
+                _ShowMenuBarItem.Active = value;
+            }
+        }
+
         public bool CaretMode {
             get {
                 return _CaretMode;
@@ -124,6 +144,20 @@ namespace Smuxi.Frontend.Gnome
             }
         }
 
+        public bool IsFullscreen {
+            get {
+                return _IsFullscreen;
+            }
+            set {
+                _IsFullscreen = value;
+                if (value) {
+                    Fullscreen();
+                } else {
+                    Unfullscreen();
+                }
+            }
+        }
+
         public EventHandler Minimized;
         public EventHandler Unminimized;
 
@@ -144,6 +178,9 @@ namespace Smuxi.Frontend.Gnome
             if (width == -1 && heigth == -1) {
                 SetDefaultSize(800, 600);
                 Maximize();
+            } else if (width == 0 && heigth == 0) {
+                // HACK: map 0/0 to default size as it crashes on Windows :/
+                SetDefaultSize(800, 600);
             } else {
                 SetDefaultSize(width, heigth);
             }
@@ -169,15 +206,13 @@ namespace Smuxi.Frontend.Gnome
             FocusInEvent += OnFocusInEvent;
             FocusOutEvent += OnFocusOutEvent;
             WindowStateEvent += OnWindowStateEvent;
-                    
-            
-            
+
             Gtk.AccelGroup agrp = new Gtk.AccelGroup();
             Gtk.AccelKey   akey;
             AddAccelGroup(agrp);
             
             // Menu
-            Gtk.MenuBar mb = new Gtk.MenuBar();
+            _MenuBar = new Gtk.MenuBar();
             Gtk.Menu menu;
             Gtk.MenuItem item;
             Gtk.ImageMenuItem image_item;
@@ -186,7 +221,7 @@ namespace Smuxi.Frontend.Gnome
             menu = new Gtk.Menu();
             item = new Gtk.MenuItem(_("_File"));
             item.Submenu = menu;
-            mb.Append(item);
+            _MenuBar.Append(item);
 
             item = new Gtk.ImageMenuItem(Gtk.Stock.Preferences, agrp);
             item.Activated += new EventHandler(_OnPreferencesButtonClicked);
@@ -202,7 +237,7 @@ namespace Smuxi.Frontend.Gnome
             menu = new Gtk.Menu();
             item = new Gtk.MenuItem(_("_Server"));
             item.Submenu = menu;
-            mb.Append(item);
+            _MenuBar.Append(item);
             
             image_item = new Gtk.ImageMenuItem(_("_Quick Connect"));
             image_item.Image = new Gtk.Image(Gtk.Stock.Connect, Gtk.IconSize.Menu);
@@ -224,7 +259,7 @@ namespace Smuxi.Frontend.Gnome
             menu = new Gtk.Menu();
             item = new Gtk.MenuItem(_("_Chat"));
             item.Submenu = menu;
-            mb.Append(item);
+            _MenuBar.Append(item);
             
             image_item = new Gtk.ImageMenuItem(_("Open / Join Chat"));
             image_item.Image = new Gtk.Image(Gtk.Stock.Open, Gtk.IconSize.Menu);
@@ -298,7 +333,19 @@ namespace Smuxi.Frontend.Gnome
             item.AddAccelerator("activate", agrp, akey);
             menu.Append(item);
             */
-            
+
+            // ROFL: the empty code statement below is needed to keep stupid
+            // gettext away from using all the commented code from above as
+            // translator comment
+            ;
+            _OpenLogChatMenuItem = new Gtk.ImageMenuItem(_("Open Log"));
+            _OpenLogChatMenuItem.Image = new Gtk.Image(Gtk.Stock.Open,
+                                                       Gtk.IconSize.Menu);
+            _OpenLogChatMenuItem.Activated += OnOpenLogChatMenuItemActivated;
+            _OpenLogChatMenuItem.Sensitive = false;
+            _OpenLogChatMenuItem.NoShowAll = true;
+            menu.Append(_OpenLogChatMenuItem);
+
             _CloseChatMenuItem = new Gtk.ImageMenuItem(Gtk.Stock.Close, agrp);
             _CloseChatMenuItem.Activated += OnCloseChatMenuItemActivated;
             menu.Append(_CloseChatMenuItem);
@@ -307,7 +354,7 @@ namespace Smuxi.Frontend.Gnome
             menu = new Gtk.Menu();
             item = new Gtk.MenuItem(_("_Engine"));
             item.Submenu = menu;
-            mb.Append(item);
+            _MenuBar.Append(item);
 
             item = new Gtk.MenuItem(_("_Use Local Engine"));
             item.Activated += new EventHandler(_OnUseLocalEngineButtonClicked);
@@ -329,7 +376,7 @@ namespace Smuxi.Frontend.Gnome
             menu = new Gtk.Menu();
             item = new Gtk.MenuItem(_("_View"));
             item.Submenu = menu;
-            mb.Append(item);
+            _MenuBar.Append(item);
             
             item = new Gtk.CheckMenuItem(_("_Caret Mode"));
             item.Activated += new EventHandler(_OnCaretModeButtonClicked);
@@ -339,11 +386,50 @@ namespace Smuxi.Frontend.Gnome
             item.AddAccelerator("activate", agrp, akey);
             menu.Append(item);
             
+            item = new Gtk.CheckMenuItem(_("_Browse Mode"));
+            item.Activated += delegate {
+                try {
+                    _Notebook.IsBrowseModeEnabled = !_Notebook.IsBrowseModeEnabled;
+                } catch (Exception ex) {
+                    Frontend.ShowException(this, ex);
+                }
+            };
+            akey = new Gtk.AccelKey();
+            akey.AccelFlags = Gtk.AccelFlags.Visible;
+            akey.Key = Gdk.Key.F8;
+            item.AddAccelerator("activate", agrp, akey);
+            menu.Append(item);
+
+            _ShowMenuBarItem = new Gtk.CheckMenuItem(_("Show _Menubar"));
+            _ShowMenuBarItem.Active = true;
+            _ShowMenuBarItem.Activated += delegate {
+                try {
+                    _MenuBar.Visible = !_MenuBar.Visible;
+                } catch (Exception ex) {
+                    Frontend.ShowException(this, ex);
+                }
+            };
+            menu.Append(_ShowMenuBarItem);
+
+            item = new Gtk.ImageMenuItem(Gtk.Stock.Fullscreen, agrp);
+            item.Activated += delegate {
+                try {
+                    IsFullscreen = !IsFullscreen;
+                } catch (Exception ex) {
+                    Frontend.ShowException(this, ex);
+                }
+            };
+            akey = new Gtk.AccelKey();
+            akey.AccelFlags = Gtk.AccelFlags.Visible;
+            akey.Key = Gdk.Key.F11;
+            item.AddAccelerator("activate", agrp, akey);
+            menu.Append(item);
+
             // Menu - Help
             menu = new Gtk.Menu();
             item = new Gtk.MenuItem(_("_Help"));
             item.Submenu = menu;
-            mb.Append(item);
+            _MenuBar.Append(item);
             
             image_item = new Gtk.ImageMenuItem(Gtk.Stock.About, agrp);
             image_item.Activated += new EventHandler(_OnAboutButtonClicked);
@@ -364,6 +450,12 @@ namespace Smuxi.Frontend.Gnome
 #if GTK_SHARP_2_10
             _StatusIconManager = new StatusIconManager(this, _ChatViewManager);
 #endif
+#if INDICATE_SHARP
+            _IndicateManager = new IndicateManager(this, _ChatViewManager);
+#endif
+#if NOTIFY_SHARP
+            _NotifyManager = new NotifyManager(this, _ChatViewManager);
+#endif
 
             _UI = new GnomeUI(_ChatViewManager);
             
@@ -375,7 +467,7 @@ namespace Smuxi.Frontend.Gnome
             _ProgressBar = new Gtk.ProgressBar();
             
             Gtk.VBox vbox = new Gtk.VBox();
-            vbox.PackStart(mb, false, false, 0);
+            vbox.PackStart(_MenuBar, false, false, 0);
             vbox.PackStart(_Notebook, true, true, 0);
             vbox.PackStart(_Entry, false, false, 0);
 
@@ -384,6 +476,7 @@ namespace Smuxi.Frontend.Gnome
             _NetworkStatusbar.HasResizeGrip = false;
             
             _Statusbar = new Gtk.Statusbar();
+            _Statusbar.HasResizeGrip = false;
             
             Gtk.HBox status_bar_hbox = new Gtk.HBox();
             status_bar_hbox.Homogeneous = true;
@@ -412,9 +505,17 @@ namespace Smuxi.Frontend.Gnome
                 modeStr
             );
             _NotificationAreaIconMode = mode;
-            
+
+            _OpenLogChatMenuItem.Visible = Frontend.IsLocalEngine;
+
 #if GTK_SHARP_2_10
             _StatusIconManager.ApplyConfig(userConfig);
+#endif
+#if INDICATE_SHARP
+            _IndicateManager.ApplyConfig(userConfig);
+#endif
+#if NOTIFY_SHARP
+            _NotifyManager.ApplyConfig(userConfig);
 #endif
             _Entry.ApplyConfig(userConfig);
             _Notebook.ApplyConfig(userConfig);
@@ -498,12 +599,12 @@ namespace Smuxi.Frontend.Gnome
                     chatView.HasHighlight = false;
                     chatView.HasActivity = false;
                     var lastMsg = chatView.OutputMessageTextView.LastMessage;
+                    if (lastMsg == null) {
+                        return;
+                    }
                     // update last seen highlight
                     ThreadPool.QueueUserWorkItem(delegate {
                         try {
-                            if (lastMsg == null) {
-                                return;
-                            }
                             // REMOTING CALL 1
                             chatView.ChatModel.LastSeenHighlight = lastMsg.TimeStamp;
                         } catch (Exception ex) {
@@ -524,6 +625,10 @@ namespace Smuxi.Frontend.Gnome
 
             try {
                 var chatView = _Notebook.CurrentChatView;
+                if (chatView == null) {
+                    return;
+                }
+
                 chatView.OutputMessageTextView.UpdateMarkerline();
             } catch (Exception ex) {
                 Frontend.ShowException(this, ex);
@@ -550,7 +655,14 @@ namespace Smuxi.Frontend.Gnome
 #endif
                 }
                 
-                Frontend.Session.Connect(server, Frontend.FrontendManager);
+                // do connect as background task as it might take a while
+                ThreadPool.QueueUserWorkItem(delegate {
+                    try {
+                        Frontend.Session.Connect(server, Frontend.FrontendManager);
+                    } catch (Exception ex) {
+                        Frontend.ShowException(this, ex);
+                    }
+                });
             } catch (Exception ex) {
                 Frontend.ShowException(this, ex);
             }
@@ -561,15 +673,14 @@ namespace Smuxi.Frontend.Gnome
         {
             Trace.Call(sender, e);
             
+            ServerDialog dialog = null;
             try {
                 ServerListController controller = new ServerListController(Frontend.UserConfig);
-                ServerDialog dialog = new ServerDialog(this,
-                                                       null,
-                                                       Frontend.Session.GetSupportedProtocols(),
-                                                       controller.GetNetworks());
+                dialog = new ServerDialog(this, null,
+                                          Frontend.Session.GetSupportedProtocols(),
+                                          controller.GetNetworks());
                 int res = dialog.Run();
                 ServerModel server = dialog.GetServer();
-                dialog.Destroy();
                 if (res != (int) Gtk.ResponseType.Ok) {
                     return;
                 }
@@ -580,6 +691,10 @@ namespace Smuxi.Frontend.Gnome
                 Frontend.ShowError(this, _("Unable to add server: "), ex);
             } catch (Exception ex) {
                 Frontend.ShowException(this, ex);
+            } finally {
+                if (dialog != null) {
+                    dialog.Destroy();
+                }
             }
         }
 
@@ -714,7 +829,24 @@ namespace Smuxi.Frontend.Gnome
                 Frontend.ShowException(this, ex);
             }
         }
-        
+
+        protected virtual void OnOpenLogChatMenuItemActivated(object sender, EventArgs e)
+        {
+            Trace.Call(sender, e);
+
+            try {
+                ThreadPool.QueueUserWorkItem(delegate {
+                    try {
+                        SysDiag.Process.Start(_Notebook.CurrentChatView.ChatModel.LogFile);
+                    } catch (Exception ex) {
+                        Frontend.ShowError(this, ex);
+                    }
+                });
+            } catch (Exception ex) {
+                Frontend.ShowException(this, ex);
+            }
+        }
+
         protected virtual void OnNextChatMenuItemActivated(object sender, EventArgs e)
         {
             Trace.Call(sender, e);
@@ -789,6 +921,10 @@ namespace Smuxi.Frontend.Gnome
             
             try {
                 _CloseChatMenuItem.Sensitive = !(_Notebook.CurrentChatView is SessionChatView);
+                if (Frontend.IsLocalEngine) {
+                    _OpenLogChatMenuItem.Sensitive =
+                        File.Exists(_Notebook.CurrentChatView.ChatModel.LogFile);
+                }
             } catch (Exception ex) {
                 Frontend.ShowException(this, ex);
             }
