@@ -40,13 +40,49 @@ namespace Smuxi.Frontend.Gnome
 #endif
         //private Gtk.Menu     _QueryTabMenu;
         private TaskQueue f_SwitchPageQueue;
+        private bool      f_IsBrowseModeEnabled;
 
         public ChatView CurrentChatView {
             get {
                 return (ChatView) base.CurrentPageWidget;
             }
+            set {
+                if (value == null) {
+                    CurrentPage = 0;
+                    return;
+                }
+                CurrentPage = GetPageNumber(value);
+            }
         }
-        
+
+        public bool IsBrowseModeEnabled {
+            get {
+                return f_IsBrowseModeEnabled;
+            }
+            set {
+                if (value && !f_IsBrowseModeEnabled) {
+#if LOG4NET
+                    f_Logger.Debug("set_IsBrowseModeEnabled(): enabling browse mode");
+#endif
+                    SwitchPage -= OnBeforeSwitchPage;
+                    SwitchPage -= OnSwitchPage;
+                }
+                if (!value && f_IsBrowseModeEnabled) {
+#if LOG4NET
+                    f_Logger.Debug("set_IsBrowseModeEnabled(): disabling browse mode");
+#endif
+                    SwitchPage += OnBeforeSwitchPage;
+                    SwitchPage += OnSwitchPage;
+
+                    // HACK: force switch page event
+                    var chat = CurrentChatView;
+                    CurrentChatView = null;
+                    CurrentChatView = chat;
+                }
+                f_IsBrowseModeEnabled = value;
+            }
+        }
+
         public Notebook() : base ()
         {
             Trace.Call();
@@ -103,7 +139,19 @@ namespace Smuxi.Frontend.Gnome
         {
             return (ChatView) base.GetNthPage(pageNumber);
         }
-        
+
+        public int GetPageNumber(ChatView chatView)
+        {
+            for (int i = 0; i < NPages; i++) {
+                ChatView page = (ChatView) GetNthPage(i);
+                if (page == chatView) {
+                    return i;
+                }
+            }
+
+            return -1;
+        }
+
         public void RemoveAllPages()
         {
             Trace.Call();
@@ -112,7 +160,7 @@ namespace Smuxi.Frontend.Gnome
             // this also breaks the Frontend.ReconnectEngineToGUI() as that one
             // has to cleanup all chats regardless of a working network
             // connection
-            SwitchPage -= OnSwitchPage;
+            IsBrowseModeEnabled = true;
 
             int npages = NPages;
             CurrentPage = 0;
@@ -126,9 +174,19 @@ namespace Smuxi.Frontend.Gnome
             }
 
             // reconnect the event handler
-            SwitchPage += OnSwitchPage;
+            IsBrowseModeEnabled = false;
         }
-        
+
+        public void SyncPagePositions()
+        {
+            Trace.Call();
+
+            for (int i = 0; i < NPages; i++) {
+                var chatView = (ChatView) GetNthPage(i);
+                chatView.ChatModel.Position = i;
+            }
+        }
+
         public void ClearAllActivity()
         {
             Trace.Call();
@@ -197,6 +255,9 @@ namespace Smuxi.Frontend.Gnome
                 // REMOTING CALL 1
                 IProtocolManager nmanager = chatModel.ProtocolManager;
 
+                // TODO: only set the protocol manager and update network
+                // status if the protocol manager differs from the old one
+
                 // REMOTING CALL 2
                 Frontend.FrontendManager.CurrentChat = chatModel;
                 if (nmanager != null) {
