@@ -64,7 +64,20 @@ namespace Smuxi.Frontend.Gnome
                 return _ChatModel;
             }
         }
-        
+
+        // this property is thread-safe
+        public bool IsActive {
+            get {
+                // is it really safe to query a property value of glib owned
+                // object?!?
+                return Frontend.MainWindow.HasToplevelFocus &&
+                        Object.ReferenceEquals(
+                            Frontend.MainWindow.Notebook.CurrentChatView,
+                            this
+                        );
+            }
+        }
+
         public bool HasHighlight {
             get {
                 return _HasHighlight;
@@ -170,7 +183,7 @@ namespace Smuxi.Frontend.Gnome
                 _OutputMessageTextView.HasFocus = value;
             }
         }
-        
+
         public Gtk.Widget LabelWidget {
             get {
                 return _TabEventBox;
@@ -219,8 +232,9 @@ namespace Smuxi.Frontend.Gnome
             tv.WrapMode = Gtk.WrapMode.Char;
             tv.MessageAdded += OnMessageTextViewMessageAdded;
             tv.MessageHighlighted += OnMessageTextViewMessageHighlighted;
+            tv.PopulatePopup += OnMessageTextViewPopulatePopup;
             _OutputMessageTextView = tv;
-            
+
             Gtk.ScrolledWindow sw = new Gtk.ScrolledWindow();
             //sw.HscrollbarPolicy = Gtk.PolicyType.Never;
             sw.HscrollbarPolicy = Gtk.PolicyType.Automatic;
@@ -502,16 +516,19 @@ namespace Smuxi.Frontend.Gnome
 #if LOG4NET
                 _Logger.Debug("OnMessageTextViewMessageHighlighted(): BEEP!");
 #endif
-                Display.Beep();
+                try {
+                    if (Display != null) {
+                        Display.Beep();
+                    }
+                } catch (Exception ex) {
+#if LOG4NET
+                    _Logger.Error("OnMessageTextViewMessageHighlighted(): Exception", ex);
+#endif
+                }
             }
 
             if (_IsSynced) {
-                bool isActiveChat =
-                    Frontend.MainWindow.HasToplevelFocus &&
-                    Object.ReferenceEquals(
-                        Frontend.MainWindow.Notebook.CurrentChatView,
-                        this
-                    );
+                bool isActiveChat = IsActive;
 
                 var method = Trace.GetMethodBase();
                 // update last seen highlight
@@ -529,6 +546,14 @@ namespace Smuxi.Frontend.Gnome
                             // REMOTING CALL 1
                             if (_ChatModel.LastSeenHighlight < e.Message.TimeStamp) {
                                 Gtk.Application.Invoke(delegate {
+                                    // we have to make sure we only highlight
+                                    // the chat if it still isn't the active
+                                    // one as isActiveChat state is probably
+                                    // obsolete by now
+                                    if (IsActive) {
+                                        return;
+                                    }
+
                                     HasHighlight = true;
                                 });
                             }
@@ -544,6 +569,33 @@ namespace Smuxi.Frontend.Gnome
             }
         }
 
+        protected virtual void OnMessageTextViewPopulatePopup(object sender, Gtk.PopulatePopupArgs e)
+        {
+            Trace.Call(sender, e);
+
+            if (OutputMessageTextView.IsAtUrlTag) {
+                return;
+            }
+            if (Frontend.MainWindow.ShowMenuBar) {
+                return;
+            }
+
+            Gtk.Menu popup = e.Menu;
+            popup.Prepend(new Gtk.SeparatorMenuItem());
+
+            var item = new Gtk.CheckMenuItem(_("Show _Menubar"));
+            item.Active = Frontend.MainWindow.ShowMenuBar;
+            item.Activated += delegate {
+                try {
+                    Frontend.MainWindow.ShowMenuBar = true;
+                } catch (Exception ex) {
+                    Frontend.ShowException(ex);
+                }
+            };
+            popup.Prepend(item);
+            popup.ShowAll();
+        }
+
         protected virtual void OnLastSeenHighlightQueueExceptionEvent(object sender, TaskQueueExceptionEventArgs e)
         {
             Trace.Call(sender, e);
